//
// anyRemote
// a bluetooth remote for your PC.
//
// Copyright (C) 2009-2012 Mikhail Fedotov <anyremote@mail.ru>
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

#ifndef _AR_DBUS_H_
#define _AR_DBUS_H_

#define TYPE_ERROR 	0
#define TYPE_INT 	1
#define TYPE_UINT 	2
#define TYPE_DOUBLE 	3
#define TYPE_BOOL 	4
#define TYPE_STRING 	5

#include "parse.h"

int  dbusInit();
void dbusFinish();
int  dbusCommand(int subtype, const char* descr, const char* cmdString, cmdParams* params);

#endif
